@@ -12,7 +12,7 @@ from strictdoc.backend.reqif.sdoc_reqif_fields import (
 from strictdoc.backend.sdoc.models.document import Document
 from strictdoc.backend.sdoc.models.document_config import DocumentConfig
 from strictdoc.backend.sdoc.models.document_grammar import DocumentGrammar
-from strictdoc.backend.sdoc.models.reference import Reference
+from strictdoc.backend.sdoc.models.reference import ParentReqReference
 from strictdoc.backend.sdoc.models.requirement import (
     Requirement,
     RequirementField,
@@ -24,17 +24,9 @@ from strictdoc.helpers.string import unescape
 class ReqIFToSDocFactory:
     @staticmethod
     def create_document(title: Optional[str]) -> Document:
-        document_config = DocumentConfig(
-            parent=None,
-            version=None,
-            uid=None,
-            markup=None,
-            auto_levels=None,
-            requirement_style=None,
-            requirement_in_toc=None,
-        )
+        document_config = DocumentConfig.default_config(None)
         document_title = title if title else "<No title>"
-        document = Document(None, document_title, document_config, None, [], [])
+        document = Document(document_title, document_config, None, [], [])
         document.grammar = DocumentGrammar.create_default(document)
         return document
 
@@ -173,9 +165,8 @@ class ReqIFToSDocFactory:
                 )
 
                 parent_refs.append(
-                    Reference(
+                    ParentReqReference(
                         requirement,
-                        "Parent",
                         parent_spec_object_parent.attribute_map[
                             foreign_key_id_or_none
                         ].value,
