@@ -3,23 +3,23 @@ from pathlib import Path
 
 from reqif.unparser import ReqIFUnparser
 
-from strictdoc.core.document_tree import DocumentTree
 from strictdoc.backend.reqif.export.sdoc_to_reqif_converter import (
     SDocToReqIFObjectConverter,
 )
+from strictdoc.core.traceability_index import TraceabilityIndex
 
 
 class ReqIFExport:
     @staticmethod
     def export(
-        document_tree: DocumentTree,
+        traceability_index: TraceabilityIndex,
         output_reqif_root: str,
     ):
         Path(output_reqif_root).mkdir(parents=True, exist_ok=True)
         output_file_path: str = os.path.join(output_reqif_root, "output.reqif")
 
         reqif_bundle = SDocToReqIFObjectConverter.convert_document_tree(
-            document_tree=document_tree
+            document_tree=traceability_index.document_tree
         )
         reqif_content: str = ReqIFUnparser.unparse(reqif_bundle)
 
