@@ -1,8 +1,10 @@
 from typing import List
 
 from strictdoc.backend.sdoc.models.inline_link import InlineLink
+from strictdoc.helpers.auto_described import auto_described
 
 
+@auto_described
 class FreeText:
     def __init__(self, parent, parts: List):
         assert isinstance(parts, list)
@@ -10,12 +12,6 @@ class FreeText:
         self.parts = parts
         self.ng_level = None
 
-    def __str__(self):
-        return f"FreeText(parts={self.parts})"
-
-    def __repr__(self):
-        return self.__str__()
-
     @property
     def is_requirement(self):
         return False
