@@ -3,6 +3,12 @@ from enum import Enum
 from strictdoc.backend.sdoc.models.document import Document
 from strictdoc.backend.sdoc.models.document_config import DocumentConfig
 from strictdoc.backend.sdoc.models.inline_link import InlineLink
+from strictdoc.backend.sdoc.models.reference import (
+    BibReference,
+    Reference,
+    FileReference,
+    ParentReqReference,
+)
 from strictdoc.backend.sdoc.models.requirement import (
     Requirement,
     CompositeRequirement,
@@ -13,6 +19,8 @@ from strictdoc.backend.sdoc.models.type_system import (
     GrammarElementFieldSingleChoice,
     GrammarElementFieldMultipleChoice,
     GrammarElementFieldTag,
+    GrammarElementFieldReference,
+    RequirementFieldType,
 )
 from strictdoc.core.document_iterator import DocumentCachingIterator
 
@@ -40,14 +48,19 @@ class SDWriter:
 
         document_config: DocumentConfig = document.config
         if document_config:
+            uid = document_config.uid
+            if uid:
+                output += f"UID: {uid}"
+                output += "\n"
+
             version = document_config.version
             if version:
                 output += f"VERSION: {version}"
                 output += "\n"
 
-            uid = document_config.uid
-            if uid:
-                output += f"UID: {uid}"
+            classification = document_config.classification
+            if classification:
+                output += f"CLASSIFICATION: {classification}"
                 output += "\n"
 
             markup = document_config.markup
@@ -176,7 +189,8 @@ class SDWriter:
                     output += f"{field_name}: >>>"
                     output += "\n"
                     if len(field.field_value_multiline) > 0:
-                        output += field.field_value_multiline.rstrip()
+                        if field.field_value_multiline != "\n":
+                            output += field.field_value_multiline
                         output += "\n"
                     output += "<<<"
                     output += "\n"
@@ -184,13 +198,35 @@ class SDWriter:
                     output += "REFS:"
                     output += "\n"
 
+                    reference: Reference
                     for reference in field.field_value_references:
                         output += "- TYPE: "
                         output += reference.ref_type
                         output += "\n"
-                        output += "  VALUE: "
-                        output += reference.path
-                        output += "\n"
+
+                        if isinstance(reference, BibReference):
+                            ref: BibReference = reference
+                            output += "  FORMAT: "
+                            output += ref.bib_entry.bib_format
+                            output += "\n"
+                            output += "  VALUE: "
+                            output += ref.bib_entry.bib_value
+                            output += "\n"
+                        elif isinstance(reference, FileReference):
+                            ref: FileReference = reference
+                            if ref.file_entry.file_format:
+                                output += "  FORMAT: "
+                                output += ref.file_entry.file_format
+                                output += "\n"
+                            output += "  VALUE: "
+                            output += ref.file_entry.file_path
+                            output += "\n"
+                        elif isinstance(reference, ParentReqReference):
+                            ref: ParentReqReference = reference
+                            output += "  VALUE: "
+                            output += ref.ref_uid
+                            output += "\n"
+
                 elif field.field_value is not None:
                     if len(field.field_value) > 0:
                         output += f"{field_name}: "
@@ -239,17 +275,24 @@ class SDWriter:
         output += "    TYPE: "
 
         if isinstance(grammar_field, GrammarElementFieldString):
-            output += "String"
+            output += RequirementFieldType.STRING
         elif isinstance(grammar_field, GrammarElementFieldSingleChoice):
-            output += "SingleChoice("
+            output += RequirementFieldType.SINGLE_CHOICE
+            output += "("
             output += ", ".join(grammar_field.options)
             output += ")"
         elif isinstance(grammar_field, GrammarElementFieldMultipleChoice):
-            output += "MultipleChoice("
+            output += RequirementFieldType.MULTIPLE_CHOICE
+            output += "("
             output += ", ".join(grammar_field.options)
             output += ")"
         elif isinstance(grammar_field, GrammarElementFieldTag):
-            output += "Tag"
+            output += RequirementFieldType.TAG
+        elif isinstance(grammar_field, GrammarElementFieldReference):
+            output += RequirementFieldType.REFERENCE
+            output += "("
+            output += ", ".join(grammar_field.types)
+            output += ")"
         else:
             raise NotImplementedError from None
 
