@@ -2,13 +2,14 @@ import os
 import sys
 
 try:
-    STRICTDOC_ROOT_PATH = os.path.abspath(
+    strictdoc_root_path = os.path.abspath(
         os.path.join(os.path.dirname(__file__), "..", "..")
     )
-    if not os.path.isdir(STRICTDOC_ROOT_PATH):
+    if not os.path.isdir(strictdoc_root_path):
         raise FileNotFoundError
-    sys.path.append(STRICTDOC_ROOT_PATH)
+    sys.path.append(strictdoc_root_path)
 
+    from strictdoc import STRICTDOC_ROOT_PATH
     from strictdoc.cli.cli_arg_parser import (
         create_sdoc_args_parser,
         ExportCommandConfig,
@@ -17,12 +18,14 @@ try:
         ImportExcelCommandConfig,
         ImportReqIFCommandConfig,
     )
+    from strictdoc.commands.about_command import AboutCommand
     from strictdoc.commands.dump_grammar_command import DumpGrammarCommand
     from strictdoc.commands.version_command import VersionCommand
     from strictdoc.core.actions.export_action import ExportAction
     from strictdoc.core.actions.import_action import ImportAction
     from strictdoc.core.actions.passthrough_action import PassthroughAction
     from strictdoc.helpers.parallelizer import Parallelizer
+    from strictdoc.server.server import run_strictdoc_server
 
 except FileNotFoundError:
     print("error: could not locate strictdoc's root folder.")
@@ -59,8 +62,13 @@ def _main(parallelizer):
             "Disabled" if config.no_parallelization else "Enabled"
         )
         print(f"Parallelization: {parallelization_value}", flush=True)
-        export_action = ExportAction()
-        export_action.export(config, parallelizer)
+        export_action = ExportAction(config, parallelizer)
+        export_action.build_index()
+        export_action.export()
+
+    elif parser.is_server_command:
+        server_config = parser.get_server_config()
+        run_strictdoc_server(config=server_config)
 
     elif parser.is_import_command_reqif:
         import_config: ImportReqIFCommandConfig = (
@@ -82,6 +90,10 @@ def _main(parallelizer):
 
     elif parser.is_version_command:
         VersionCommand.execute()
+
+    elif parser.is_about_command:
+        AboutCommand.execute()
+
     else:
         raise NotImplementedError
 
