@@ -5,6 +5,7 @@ from typing import List, Iterator, Optional
 
 from strictdoc.backend.sdoc.models.document import Document
 from strictdoc.backend.sdoc.models.inline_link import InlineLink
+from strictdoc.backend.sdoc.models.reference import ParentReqReference
 from strictdoc.backend.sdoc.models.type_system import ReferenceType
 from strictdoc.backend.sdoc.models.requirement import Requirement
 from strictdoc.backend.source_file_syntax.reader import (
@@ -161,6 +162,7 @@ class TraceabilityIndexBuilder:
         d_06_map_documents_to_children = {}
         d_07_file_traceability_index = FileTraceabilityIndex()
         d_08_requirements_children_map = {}
+        d_11_map_id_to_node = {}
 
         # It seems to be impossible to accomplish everything in just one for
         # loop. One particular problem that requires two passes: it is not
@@ -185,11 +187,15 @@ class TraceabilityIndexBuilder:
         # - Calculate depth of both parent and child links.
         document: Document
         for document in document_tree.document_list:
+            d_11_map_id_to_node[document.node_id] = document
+
             document_iterator = DocumentCachingIterator(document)
             d_01_document_iterators[document] = document_iterator
             if document.title not in d_03_map_doc_titles_to_tag_lists:
                 d_03_map_doc_titles_to_tag_lists[document.title] = {}
             for node in document_iterator.all_content():
+                d_11_map_id_to_node[node.node_id] = node
+
                 if not node.uid:
                     continue
                 if node.uid in d_02_requirements_map:
@@ -234,12 +240,15 @@ class TraceabilityIndexBuilder:
                         continue
                     if ref.ref_type != ReferenceType.PARENT:
                         continue
+                    ref: ParentReqReference
                     d_02_requirements_map[requirement.uid][
                         "parents_uids"
-                    ].append(ref.path)
-                    if ref.path not in d_08_requirements_children_map:
-                        d_08_requirements_children_map[ref.path] = []
-                    d_08_requirements_children_map[ref.path].append(requirement)
+                    ].append(ref.ref_uid)
+                    if ref.ref_uid not in d_08_requirements_children_map:
+                        d_08_requirements_children_map[ref.ref_uid] = []
+                    d_08_requirements_children_map[ref.ref_uid].append(
+                        requirement
+                    )
 
         # Now iterate over the requirements again to build an in-depth map of
         # parents and children.
@@ -340,6 +349,7 @@ class TraceabilityIndexBuilder:
             d_03_map_doc_titles_to_tag_lists,
             d_05_map_documents_to_parents,
             d_06_map_documents_to_children,
-            d_07_file_traceability_index,
+            file_traceability_index=d_07_file_traceability_index,
+            map_id_to_node=d_11_map_id_to_node,
         )
         return traceability_index
