@@ -1,14 +1,9 @@
-from jinja2 import Environment, PackageLoader, StrictUndefined
-
 from strictdoc.export.html.document_type import DocumentType
+from strictdoc.export.html.html_templates import HTMLTemplates
 
 
 class DocumentTableHTMLGenerator:
-    env = Environment(
-        loader=PackageLoader("strictdoc", "export/html/templates"),
-        undefined=StrictUndefined,
-    )
-    env.globals.update(isinstance=isinstance)
+    env = HTMLTemplates.jinja_environment
 
     @staticmethod
     def export(
